Crate taskter

Crate taskter 

Taskter library interface exposing the core modules so they can be reused from integration tests and (potentially) other binaries.

Re-exports

pub use cli::Cli;
pub use cli::Commands;
pub use cli::ShowCommands;

Modules

agent
cli
store
tools